netapp_ontap.models.cluster_peer_local_network API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.cluster_peer_local_network`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class ClusterPeerLocalNetworkSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the ClusterPeerLocalNetwork object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `broadcast_domain GET POST PATCH`

    Broadcast domain that is in use within the IPspace.

    Example: bd1

  `gateway GET POST PATCH`

    The IPv4 or IPv6 address of the default router.

    Example: 10.1.1.1

  `interfaces GET POST PATCH`

    The interfaces field of the cluster_peer_local_network.

  `netmask GET POST PATCH`

    IPv4 mask or netmask length.

    Example: 255.255.0.0